Anonymize: Realistic random data
================================

The Anonymize extension lets generate anonymous data that resembles
real data.


.. module:: recipe

.. autoclass:: Anonymize
    :members:
    :noindex: